# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppShareVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mnt_dir': 'str',
        'mnt_name': 'str',
        'service_share_uuid': 'str'
    }

    attribute_map = {
        'mnt_dir': 'mnt_dir',
        'mnt_name': 'mnt_name',
        'service_share_uuid': 'service_share_uuid'
    }

    def __init__(self, mnt_dir=None, mnt_name=None, service_share_uuid=None):  # noqa: E501
        """StoreAppVersionTempleteAppShareVolume - a model defined in Swagger"""  # noqa: E501

        self._mnt_dir = None
        self._mnt_name = None
        self._service_share_uuid = None
        self.discriminator = None

        if mnt_dir is not None:
            self.mnt_dir = mnt_dir
        if mnt_name is not None:
            self.mnt_name = mnt_name
        if service_share_uuid is not None:
            self.service_share_uuid = service_share_uuid

    @property
    def mnt_dir(self):
        """Gets the mnt_dir of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501


        :return: The mnt_dir of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :rtype: str
        """
        return self._mnt_dir

    @mnt_dir.setter
    def mnt_dir(self, mnt_dir):
        """Sets the mnt_dir of this StoreAppVersionTempleteAppShareVolume.


        :param mnt_dir: The mnt_dir of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :type: str
        """

        self._mnt_dir = mnt_dir

    @property
    def mnt_name(self):
        """Gets the mnt_name of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501


        :return: The mnt_name of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :rtype: str
        """
        return self._mnt_name

    @mnt_name.setter
    def mnt_name(self, mnt_name):
        """Sets the mnt_name of this StoreAppVersionTempleteAppShareVolume.


        :param mnt_name: The mnt_name of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :type: str
        """

        self._mnt_name = mnt_name

    @property
    def service_share_uuid(self):
        """Gets the service_share_uuid of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501


        :return: The service_share_uuid of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :rtype: str
        """
        return self._service_share_uuid

    @service_share_uuid.setter
    def service_share_uuid(self, service_share_uuid):
        """Sets the service_share_uuid of this StoreAppVersionTempleteAppShareVolume.


        :param service_share_uuid: The service_share_uuid of this StoreAppVersionTempleteAppShareVolume.  # noqa: E501
        :type: str
        """

        self._service_share_uuid = service_share_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppShareVolume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppShareVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_content': 'str',
        'volume_name': 'str',
        'volume_path': 'str',
        'volume_type': 'str'
    }

    attribute_map = {
        'file_content': 'file_content',
        'volume_name': 'volume_name',
        'volume_path': 'volume_path',
        'volume_type': 'volume_type'
    }

    def __init__(self, file_content=None, volume_name=None, volume_path=None, volume_type=None):  # noqa: E501
        """StoreAppVersionTempleteAppVolume - a model defined in Swagger"""  # noqa: E501

        self._file_content = None
        self._volume_name = None
        self._volume_path = None
        self._volume_type = None
        self.discriminator = None

        if file_content is not None:
            self.file_content = file_content
        if volume_name is not None:
            self.volume_name = volume_name
        if volume_path is not None:
            self.volume_path = volume_path
        if volume_type is not None:
            self.volume_type = volume_type

    @property
    def file_content(self):
        """Gets the file_content of this StoreAppVersionTempleteAppVolume.  # noqa: E501

        用于配置文件，存储配置文件数据  # noqa: E501

        :return: The file_content of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :rtype: str
        """
        return self._file_content

    @file_content.setter
    def file_content(self, file_content):
        """Sets the file_content of this StoreAppVersionTempleteAppVolume.

        用于配置文件，存储配置文件数据  # noqa: E501

        :param file_content: The file_content of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :type: str
        """

        self._file_content = file_content

    @property
    def volume_name(self):
        """Gets the volume_name of this StoreAppVersionTempleteAppVolume.  # noqa: E501


        :return: The volume_name of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this StoreAppVersionTempleteAppVolume.


        :param volume_name: The volume_name of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :type: str
        """

        self._volume_name = volume_name

    @property
    def volume_path(self):
        """Gets the volume_path of this StoreAppVersionTempleteAppVolume.  # noqa: E501


        :return: The volume_path of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_path

    @volume_path.setter
    def volume_path(self, volume_path):
        """Sets the volume_path of this StoreAppVersionTempleteAppVolume.


        :param volume_path: The volume_path of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :type: str
        """

        self._volume_path = volume_path

    @property
    def volume_type(self):
        """Gets the volume_type of this StoreAppVersionTempleteAppVolume.  # noqa: E501


        :return: The volume_type of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :rtype: str
        """
        return self._volume_type

    @volume_type.setter
    def volume_type(self, volume_type):
        """Sets the volume_type of this StoreAppVersionTempleteAppVolume.


        :param volume_type: The volume_type of this StoreAppVersionTempleteAppVolume.  # noqa: E501
        :type: str
        """

        self._volume_type = volume_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppVolume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.store_app_version_templete import StoreAppVersionTemplete  # noqa: F401,E501


class StoreAppVersion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_key_id': 'str',
        'app_version': 'str',
        'create_time': 'datetime',
        'desc': 'str',
        'rainbond_version': 'str',
        'templete': 'StoreAppVersionTemplete',
        'templete_version': 'str',
        'update_time': 'datetime',
        'update_version': 'int'
    }

    attribute_map = {
        'app_key_id': 'app_key_id',
        'app_version': 'app_version',
        'create_time': 'create_time',
        'desc': 'desc',
        'rainbond_version': 'rainbond_version',
        'templete': 'templete',
        'templete_version': 'templete_version',
        'update_time': 'update_time',
        'update_version': 'update_version'
    }

    def __init__(self, app_key_id=None, app_version=None, create_time=None, desc=None, rainbond_version=None, templete=None, templete_version=None, update_time=None, update_version=None):  # noqa: E501
        """StoreAppVersion - a model defined in Swagger"""  # noqa: E501

        self._app_key_id = None
        self._app_version = None
        self._create_time = None
        self._desc = None
        self._rainbond_version = None
        self._templete = None
        self._templete_version = None
        self._update_time = None
        self._update_version = None
        self.discriminator = None

        if app_key_id is not None:
            self.app_key_id = app_key_id
        if app_version is not None:
            self.app_version = app_version
        if create_time is not None:
            self.create_time = create_time
        if desc is not None:
            self.desc = desc
        if rainbond_version is not None:
            self.rainbond_version = rainbond_version
        if templete is not None:
            self.templete = templete
        if templete_version is not None:
            self.templete_version = templete_version
        if update_time is not None:
            self.update_time = update_time
        if update_version is not None:
            self.update_version = update_version

    @property
    def app_key_id(self):
        """Gets the app_key_id of this StoreAppVersion.  # noqa: E501


        :return: The app_key_id of this StoreAppVersion.  # noqa: E501
        :rtype: str
        """
        return self._app_key_id

    @app_key_id.setter
    def app_key_id(self, app_key_id):
        """Sets the app_key_id of this StoreAppVersion.


        :param app_key_id: The app_key_id of this StoreAppVersion.  # noqa: E501
        :type: str
        """

        self._app_key_id = app_key_id

    @property
    def app_version(self):
        """Gets the app_version of this StoreAppVersion.  # noqa: E501


        :return: The app_version of this StoreAppVersion.  # noqa: E501
        :rtype: str
        """
        return self._app_version

    @app_version.setter
    def app_version(self, app_version):
        """Sets the app_version of this StoreAppVersion.


        :param app_version: The app_version of this StoreAppVersion.  # noqa: E501
        :type: str
        """

        self._app_version = app_version

    @property
    def create_time(self):
        """Gets the create_time of this StoreAppVersion.  # noqa: E501


        :return: The create_time of this StoreAppVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this StoreAppVersion.


        :param create_time: The create_time of this StoreAppVersion.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def desc(self):
        """Gets the desc of this StoreAppVersion.  # noqa: E501


        :return: The desc of this StoreAppVersion.  # noqa: E501
        :rtype: str
        """
        return self._desc

    @desc.setter
    def desc(self, desc):
        """Sets the desc of this StoreAppVersion.


        :param desc: The desc of this StoreAppVersion.  # noqa: E501
        :type: str
        """

        self._desc = desc

    @property
    def rainbond_version(self):
        """Gets the rainbond_version of this StoreAppVersion.  # noqa: E501


        :return: The rainbond_version of this StoreAppVersion.  # noqa: E501
        :rtype: str
        """
        return self._rainbond_version

    @rainbond_version.setter
    def rainbond_version(self, rainbond_version):
        """Sets the rainbond_version of this StoreAppVersion.


        :param rainbond_version: The rainbond_version of this StoreAppVersion.  # noqa: E501
        :type: str
        """

        self._rainbond_version = rainbond_version

    @property
    def templete(self):
        """Gets the templete of this StoreAppVersion.  # noqa: E501


        :return: The templete of this StoreAppVersion.  # noqa: E501
        :rtype: StoreAppVersionTemplete
        """
        return self._templete

    @templete.setter
    def templete(self, templete):
        """Sets the templete of this StoreAppVersion.


        :param templete: The templete of this StoreAppVersion.  # noqa: E501
        :type: StoreAppVersionTemplete
        """

        self._templete = templete

    @property
    def templete_version(self):
        """Gets the templete_version of this StoreAppVersion.  # noqa: E501


        :return: The templete_version of this StoreAppVersion.  # noqa: E501
        :rtype: str
        """
        return self._templete_version

    @templete_version.setter
    def templete_version(self, templete_version):
        """Sets the templete_version of this StoreAppVersion.


        :param templete_version: The templete_version of this StoreAppVersion.  # noqa: E501
        :type: str
        """

        self._templete_version = templete_version

    @property
    def update_time(self):
        """Gets the update_time of this StoreAppVersion.  # noqa: E501


        :return: The update_time of this StoreAppVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this StoreAppVersion.


        :param update_time: The update_time of this StoreAppVersion.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    @property
    def update_version(self):
        """Gets the update_version of this StoreAppVersion.  # noqa: E501


        :return: The update_version of this StoreAppVersion.  # noqa: E501
        :rtype: int
        """
        return self._update_version

    @update_version.setter
    def update_version(self, update_version):
        """Sets the update_version of this StoreAppVersion.


        :param update_version: The update_version of this StoreAppVersion.  # noqa: E501
        :type: int
        """

        self._update_version = update_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.apps_api import AppsApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.app_list_request import AppListRequest
from swagger_client.models.app_list_response import AppListResponse
from swagger_client.models.error_api_response import ErrorAPIResponse
from swagger_client.models.image_info import ImageInfo
from swagger_client.models.store_app import StoreApp
from swagger_client.models.store_app_scope import StoreAppScope
from swagger_client.models.store_app_tag import StoreAppTag
from swagger_client.models.store_app_type import StoreAppType
from swagger_client.models.store_app_version import StoreAppVersion
from swagger_client.models.store_app_version_templete import StoreAppVersionTemplete
from swagger_client.models.store_app_version_templete_app import StoreAppVersionTempleteApp
from swagger_client.models.store_app_version_templete_app_dep_service import StoreAppVersionTempleteAppDepService
from swagger_client.models.store_app_version_templete_app_env import StoreAppVersionTempleteAppEnv
from swagger_client.models.store_app_version_templete_app_extend_method_rule import StoreAppVersionTempleteAppExtendMethodRule
from swagger_client.models.store_app_version_templete_app_plugin_config import StoreAppVersionTempleteAppPluginConfig
from swagger_client.models.store_app_version_templete_app_port import StoreAppVersionTempleteAppPort
from swagger_client.models.store_app_version_templete_app_probe import StoreAppVersionTempleteAppProbe
from swagger_client.models.store_app_version_templete_app_share_volume import StoreAppVersionTempleteAppShareVolume
from swagger_client.models.store_app_version_templete_app_volume import StoreAppVersionTempleteAppVolume
from swagger_client.models.store_app_version_templete_plugin import StoreAppVersionTempletePlugin
from swagger_client.models.store_app_version_templete_plugin_config_group import StoreAppVersionTempletePluginConfigGroup
from swagger_client.models.store_app_version_templete_plugin_config_group_option import StoreAppVersionTempletePluginConfigGroupOption



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.store_app_version_templete_plugin_config_group_option import StoreAppVersionTempletePluginConfigGroupOption  # noqa: F401,E501


class StoreAppVersionTempletePluginConfigGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'build_version': 'str',
        'config_name': 'str',
        'injection': 'str',
        'options': 'list[StoreAppVersionTempletePluginConfigGroupOption]',
        'plugin_id': 'str',
        'service_meta_type': 'str'
    }

    attribute_map = {
        'id': 'ID',
        'build_version': 'build_version',
        'config_name': 'config_name',
        'injection': 'injection',
        'options': 'options',
        'plugin_id': 'plugin_id',
        'service_meta_type': 'service_meta_type'
    }

    def __init__(self, id=None, build_version=None, config_name=None, injection=None, options=None, plugin_id=None, service_meta_type=None):  # noqa: E501
        """StoreAppVersionTempletePluginConfigGroup - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._build_version = None
        self._config_name = None
        self._injection = None
        self._options = None
        self._plugin_id = None
        self._service_meta_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if build_version is not None:
            self.build_version = build_version
        if config_name is not None:
            self.config_name = config_name
        if injection is not None:
            self.injection = injection
        if options is not None:
            self.options = options
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if service_meta_type is not None:
            self.service_meta_type = service_meta_type

    @property
    def id(self):
        """Gets the id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StoreAppVersionTempletePluginConfigGroup.


        :param id: The id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def build_version(self):
        """Gets the build_version of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The build_version of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: str
        """
        return self._build_version

    @build_version.setter
    def build_version(self, build_version):
        """Sets the build_version of this StoreAppVersionTempletePluginConfigGroup.


        :param build_version: The build_version of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: str
        """

        self._build_version = build_version

    @property
    def config_name(self):
        """Gets the config_name of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The config_name of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: str
        """
        return self._config_name

    @config_name.setter
    def config_name(self, config_name):
        """Sets the config_name of this StoreAppVersionTempletePluginConfigGroup.


        :param config_name: The config_name of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: str
        """

        self._config_name = config_name

    @property
    def injection(self):
        """Gets the injection of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The injection of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: str
        """
        return self._injection

    @injection.setter
    def injection(self, injection):
        """Sets the injection of this StoreAppVersionTempletePluginConfigGroup.


        :param injection: The injection of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: str
        """

        self._injection = injection

    @property
    def options(self):
        """Gets the options of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The options of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: list[StoreAppVersionTempletePluginConfigGroupOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this StoreAppVersionTempletePluginConfigGroup.


        :param options: The options of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: list[StoreAppVersionTempletePluginConfigGroupOption]
        """

        self._options = options

    @property
    def plugin_id(self):
        """Gets the plugin_id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The plugin_id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this StoreAppVersionTempletePluginConfigGroup.


        :param plugin_id: The plugin_id of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def service_meta_type(self):
        """Gets the service_meta_type of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501


        :return: The service_meta_type of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :rtype: str
        """
        return self._service_meta_type

    @service_meta_type.setter
    def service_meta_type(self, service_meta_type):
        """Sets the service_meta_type of this StoreAppVersionTempletePluginConfigGroup.


        :param service_meta_type: The service_meta_type of this StoreAppVersionTempletePluginConfigGroup.  # noqa: E501
        :type: str
        """

        self._service_meta_type = service_meta_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempletePluginConfigGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempletePluginConfigGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class AppsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_recommended_app_list(self, **kwargs):  # noqa: E501
        """get recommended app list  # noqa: E501

        This will show recommended app  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recommended_app_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: current page number
        :param int limit: current page limit number
        :param int group_name: search for application name
        :param str x_enterprise_id: client enterprise id
        :return: AppListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recommended_app_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_recommended_app_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_recommended_app_list_with_http_info(self, **kwargs):  # noqa: E501
        """get recommended app list  # noqa: E501

        This will show recommended app  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recommended_app_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: current page number
        :param int limit: current page limit number
        :param int group_name: search for application name
        :param str x_enterprise_id: client enterprise id
        :return: AppListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'limit', 'group_name', 'x_enterprise_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recommended_app_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'group_name' in params:
            query_params.append(('group_name', params['group_name']))  # noqa: E501

        header_params = {}
        if 'x_enterprise_id' in params:
            header_params['X_ENTERPRISE_ID'] = params['x_enterprise_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['enterprise_key', 'token_key']  # noqa: E501

        return self.api_client.call_api(
            '/openapi/v2/recommended/apps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AppListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppPort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'container_port': 'int',
        'is_inner_service': 'bool',
        'is_outer_service': 'bool',
        'port_alias': 'str',
        'protocol': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'container_port': 'container_port',
        'is_inner_service': 'is_inner_service',
        'is_outer_service': 'is_outer_service',
        'port_alias': 'port_alias',
        'protocol': 'protocol',
        'tenant_id': 'tenant_id'
    }

    def __init__(self, container_port=None, is_inner_service=None, is_outer_service=None, port_alias=None, protocol=None, tenant_id=None):  # noqa: E501
        """StoreAppVersionTempleteAppPort - a model defined in Swagger"""  # noqa: E501

        self._container_port = None
        self._is_inner_service = None
        self._is_outer_service = None
        self._port_alias = None
        self._protocol = None
        self._tenant_id = None
        self.discriminator = None

        if container_port is not None:
            self.container_port = container_port
        if is_inner_service is not None:
            self.is_inner_service = is_inner_service
        if is_outer_service is not None:
            self.is_outer_service = is_outer_service
        if port_alias is not None:
            self.port_alias = port_alias
        if protocol is not None:
            self.protocol = protocol
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def container_port(self):
        """Gets the container_port of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The container_port of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: int
        """
        return self._container_port

    @container_port.setter
    def container_port(self, container_port):
        """Sets the container_port of this StoreAppVersionTempleteAppPort.


        :param container_port: The container_port of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: int
        """

        self._container_port = container_port

    @property
    def is_inner_service(self):
        """Gets the is_inner_service of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The is_inner_service of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: bool
        """
        return self._is_inner_service

    @is_inner_service.setter
    def is_inner_service(self, is_inner_service):
        """Sets the is_inner_service of this StoreAppVersionTempleteAppPort.


        :param is_inner_service: The is_inner_service of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: bool
        """

        self._is_inner_service = is_inner_service

    @property
    def is_outer_service(self):
        """Gets the is_outer_service of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The is_outer_service of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: bool
        """
        return self._is_outer_service

    @is_outer_service.setter
    def is_outer_service(self, is_outer_service):
        """Sets the is_outer_service of this StoreAppVersionTempleteAppPort.


        :param is_outer_service: The is_outer_service of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: bool
        """

        self._is_outer_service = is_outer_service

    @property
    def port_alias(self):
        """Gets the port_alias of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The port_alias of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: str
        """
        return self._port_alias

    @port_alias.setter
    def port_alias(self, port_alias):
        """Sets the port_alias of this StoreAppVersionTempleteAppPort.


        :param port_alias: The port_alias of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: str
        """

        self._port_alias = port_alias

    @property
    def protocol(self):
        """Gets the protocol of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The protocol of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this StoreAppVersionTempleteAppPort.


        :param protocol: The protocol of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def tenant_id(self):
        """Gets the tenant_id of this StoreAppVersionTempleteAppPort.  # noqa: E501


        :return: The tenant_id of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this StoreAppVersionTempleteAppPort.


        :param tenant_id: The tenant_id of this StoreAppVersionTempleteAppPort.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppPort, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppPort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AppListRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'x_enterprise_id': 'str',
        'group_name': 'int',
        'limit': 'int',
        'page': 'int'
    }

    attribute_map = {
        'x_enterprise_id': 'X_ENTERPRISE_ID',
        'group_name': 'group_name',
        'limit': 'limit',
        'page': 'page'
    }

    def __init__(self, x_enterprise_id=None, group_name=None, limit=None, page=None):  # noqa: E501
        """AppListRequest - a model defined in Swagger"""  # noqa: E501

        self._x_enterprise_id = None
        self._group_name = None
        self._limit = None
        self._page = None
        self.discriminator = None

        if x_enterprise_id is not None:
            self.x_enterprise_id = x_enterprise_id
        if group_name is not None:
            self.group_name = group_name
        if limit is not None:
            self.limit = limit
        if page is not None:
            self.page = page

    @property
    def x_enterprise_id(self):
        """Gets the x_enterprise_id of this AppListRequest.  # noqa: E501

        client enterprise id In: header  # noqa: E501

        :return: The x_enterprise_id of this AppListRequest.  # noqa: E501
        :rtype: str
        """
        return self._x_enterprise_id

    @x_enterprise_id.setter
    def x_enterprise_id(self, x_enterprise_id):
        """Sets the x_enterprise_id of this AppListRequest.

        client enterprise id In: header  # noqa: E501

        :param x_enterprise_id: The x_enterprise_id of this AppListRequest.  # noqa: E501
        :type: str
        """

        self._x_enterprise_id = x_enterprise_id

    @property
    def group_name(self):
        """Gets the group_name of this AppListRequest.  # noqa: E501

        search for application name  In: query  # noqa: E501

        :return: The group_name of this AppListRequest.  # noqa: E501
        :rtype: int
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this AppListRequest.

        search for application name  In: query  # noqa: E501

        :param group_name: The group_name of this AppListRequest.  # noqa: E501
        :type: int
        """

        self._group_name = group_name

    @property
    def limit(self):
        """Gets the limit of this AppListRequest.  # noqa: E501

        current page limit number  In: query  # noqa: E501

        :return: The limit of this AppListRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this AppListRequest.

        current page limit number  In: query  # noqa: E501

        :param limit: The limit of this AppListRequest.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def page(self):
        """Gets the page of this AppListRequest.  # noqa: E501

        current page number  In: query  # noqa: E501

        :return: The page of this AppListRequest.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this AppListRequest.

        current page number  In: query  # noqa: E501

        :param page: The page of this AppListRequest.  # noqa: E501
        :type: int
        """

        self._page = page

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppListRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppListRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_type_desc': 'str',
        'app_type_id': 'str',
        'app_type_name': 'str',
        'enterprise_id': 'str',
        'sort': 'int'
    }

    attribute_map = {
        'app_type_desc': 'app_type_desc',
        'app_type_id': 'app_type_id',
        'app_type_name': 'app_type_name',
        'enterprise_id': 'enterprise_id',
        'sort': 'sort'
    }

    def __init__(self, app_type_desc=None, app_type_id=None, app_type_name=None, enterprise_id=None, sort=None):  # noqa: E501
        """StoreAppType - a model defined in Swagger"""  # noqa: E501

        self._app_type_desc = None
        self._app_type_id = None
        self._app_type_name = None
        self._enterprise_id = None
        self._sort = None
        self.discriminator = None

        if app_type_desc is not None:
            self.app_type_desc = app_type_desc
        if app_type_id is not None:
            self.app_type_id = app_type_id
        if app_type_name is not None:
            self.app_type_name = app_type_name
        if enterprise_id is not None:
            self.enterprise_id = enterprise_id
        if sort is not None:
            self.sort = sort

    @property
    def app_type_desc(self):
        """Gets the app_type_desc of this StoreAppType.  # noqa: E501


        :return: The app_type_desc of this StoreAppType.  # noqa: E501
        :rtype: str
        """
        return self._app_type_desc

    @app_type_desc.setter
    def app_type_desc(self, app_type_desc):
        """Sets the app_type_desc of this StoreAppType.


        :param app_type_desc: The app_type_desc of this StoreAppType.  # noqa: E501
        :type: str
        """

        self._app_type_desc = app_type_desc

    @property
    def app_type_id(self):
        """Gets the app_type_id of this StoreAppType.  # noqa: E501


        :return: The app_type_id of this StoreAppType.  # noqa: E501
        :rtype: str
        """
        return self._app_type_id

    @app_type_id.setter
    def app_type_id(self, app_type_id):
        """Sets the app_type_id of this StoreAppType.


        :param app_type_id: The app_type_id of this StoreAppType.  # noqa: E501
        :type: str
        """

        self._app_type_id = app_type_id

    @property
    def app_type_name(self):
        """Gets the app_type_name of this StoreAppType.  # noqa: E501


        :return: The app_type_name of this StoreAppType.  # noqa: E501
        :rtype: str
        """
        return self._app_type_name

    @app_type_name.setter
    def app_type_name(self, app_type_name):
        """Sets the app_type_name of this StoreAppType.


        :param app_type_name: The app_type_name of this StoreAppType.  # noqa: E501
        :type: str
        """

        self._app_type_name = app_type_name

    @property
    def enterprise_id(self):
        """Gets the enterprise_id of this StoreAppType.  # noqa: E501


        :return: The enterprise_id of this StoreAppType.  # noqa: E501
        :rtype: str
        """
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, enterprise_id):
        """Sets the enterprise_id of this StoreAppType.


        :param enterprise_id: The enterprise_id of this StoreAppType.  # noqa: E501
        :type: str
        """

        self._enterprise_id = enterprise_id

    @property
    def sort(self):
        """Gets the sort of this StoreAppType.  # noqa: E501


        :return: The sort of this StoreAppType.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this StoreAppType.


        :param sort: The sort of this StoreAppType.  # noqa: E501
        :type: int
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.store_app_tag import StoreAppTag  # noqa: F401,E501
from swagger_client.models.store_app_version import StoreAppVersion  # noqa: F401,E501


class StoreApp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_key_id': 'str',
        'app_tag_ids': 'list[str]',
        'app_tags': 'list[StoreAppTag]',
        'app_type_id': 'str',
        'app_versions': 'list[StoreAppVersion]',
        'code_page': 'str',
        'create_time': 'datetime',
        'desc': 'str',
        'download_count': 'int',
        'enterprise_id': 'str',
        'home_page': 'str',
        'install_count': 'int',
        'install_status': 'bool',
        'introduction': 'str',
        'is_official': 'bool',
        'joint_cloud_id': 'str',
        'logo': 'str',
        'name': 'str',
        'pic': 'list[str]',
        'price': 'float',
        'publish_type': 'str',
        'show_count': 'int',
        'start_count': 'int',
        'status': 'str',
        'update_time': 'datetime'
    }

    attribute_map = {
        'app_key_id': 'app_key_id',
        'app_tag_ids': 'app_tag_ids',
        'app_tags': 'app_tags',
        'app_type_id': 'app_type_id',
        'app_versions': 'app_versions',
        'code_page': 'code_page',
        'create_time': 'create_time',
        'desc': 'desc',
        'download_count': 'download_count',
        'enterprise_id': 'enterprise_id',
        'home_page': 'home_page',
        'install_count': 'install_count',
        'install_status': 'install_status',
        'introduction': 'introduction',
        'is_official': 'is_official',
        'joint_cloud_id': 'joint_cloud_id',
        'logo': 'logo',
        'name': 'name',
        'pic': 'pic',
        'price': 'price',
        'publish_type': 'publish_type',
        'show_count': 'show_count',
        'start_count': 'start_count',
        'status': 'status',
        'update_time': 'update_time'
    }

    def __init__(self, app_key_id=None, app_tag_ids=None, app_tags=None, app_type_id=None, app_versions=None, code_page=None, create_time=None, desc=None, download_count=None, enterprise_id=None, home_page=None, install_count=None, install_status=None, introduction=None, is_official=None, joint_cloud_id=None, logo=None, name=None, pic=None, price=None, publish_type=None, show_count=None, start_count=None, status=None, update_time=None):  # noqa: E501
        """StoreApp - a model defined in Swagger"""  # noqa: E501

        self._app_key_id = None
        self._app_tag_ids = None
        self._app_tags = None
        self._app_type_id = None
        self._app_versions = None
        self._code_page = None
        self._create_time = None
        self._desc = None
        self._download_count = None
        self._enterprise_id = None
        self._home_page = None
        self._install_count = None
        self._install_status = None
        self._introduction = None
        self._is_official = None
        self._joint_cloud_id = None
        self._logo = None
        self._name = None
        self._pic = None
        self._price = None
        self._publish_type = None
        self._show_count = None
        self._start_count = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if app_key_id is not None:
            self.app_key_id = app_key_id
        if app_tag_ids is not None:
            self.app_tag_ids = app_tag_ids
        if app_tags is not None:
            self.app_tags = app_tags
        if app_type_id is not None:
            self.app_type_id = app_type_id
        if app_versions is not None:
            self.app_versions = app_versions
        if code_page is not None:
            self.code_page = code_page
        if create_time is not None:
            self.create_time = create_time
        if desc is not None:
            self.desc = desc
        if download_count is not None:
            self.download_count = download_count
        if enterprise_id is not None:
            self.enterprise_id = enterprise_id
        if home_page is not None:
            self.home_page = home_page
        if install_count is not None:
            self.install_count = install_count
        if install_status is not None:
            self.install_status = install_status
        if introduction is not None:
            self.introduction = introduction
        if is_official is not None:
            self.is_official = is_official
        if joint_cloud_id is not None:
            self.joint_cloud_id = joint_cloud_id
        if logo is not None:
            self.logo = logo
        if name is not None:
            self.name = name
        if pic is not None:
            self.pic = pic
        if price is not None:
            self.price = price
        if publish_type is not None:
            self.publish_type = publish_type
        if show_count is not None:
            self.show_count = show_count
        if start_count is not None:
            self.start_count = start_count
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def app_key_id(self):
        """Gets the app_key_id of this StoreApp.  # noqa: E501


        :return: The app_key_id of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._app_key_id

    @app_key_id.setter
    def app_key_id(self, app_key_id):
        """Sets the app_key_id of this StoreApp.


        :param app_key_id: The app_key_id of this StoreApp.  # noqa: E501
        :type: str
        """

        self._app_key_id = app_key_id

    @property
    def app_tag_ids(self):
        """Gets the app_tag_ids of this StoreApp.  # noqa: E501


        :return: The app_tag_ids of this StoreApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._app_tag_ids

    @app_tag_ids.setter
    def app_tag_ids(self, app_tag_ids):
        """Sets the app_tag_ids of this StoreApp.


        :param app_tag_ids: The app_tag_ids of this StoreApp.  # noqa: E501
        :type: list[str]
        """

        self._app_tag_ids = app_tag_ids

    @property
    def app_tags(self):
        """Gets the app_tags of this StoreApp.  # noqa: E501


        :return: The app_tags of this StoreApp.  # noqa: E501
        :rtype: list[StoreAppTag]
        """
        return self._app_tags

    @app_tags.setter
    def app_tags(self, app_tags):
        """Sets the app_tags of this StoreApp.


        :param app_tags: The app_tags of this StoreApp.  # noqa: E501
        :type: list[StoreAppTag]
        """

        self._app_tags = app_tags

    @property
    def app_type_id(self):
        """Gets the app_type_id of this StoreApp.  # noqa: E501


        :return: The app_type_id of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._app_type_id

    @app_type_id.setter
    def app_type_id(self, app_type_id):
        """Sets the app_type_id of this StoreApp.


        :param app_type_id: The app_type_id of this StoreApp.  # noqa: E501
        :type: str
        """

        self._app_type_id = app_type_id

    @property
    def app_versions(self):
        """Gets the app_versions of this StoreApp.  # noqa: E501


        :return: The app_versions of this StoreApp.  # noqa: E501
        :rtype: list[StoreAppVersion]
        """
        return self._app_versions

    @app_versions.setter
    def app_versions(self, app_versions):
        """Sets the app_versions of this StoreApp.


        :param app_versions: The app_versions of this StoreApp.  # noqa: E501
        :type: list[StoreAppVersion]
        """

        self._app_versions = app_versions

    @property
    def code_page(self):
        """Gets the code_page of this StoreApp.  # noqa: E501


        :return: The code_page of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._code_page

    @code_page.setter
    def code_page(self, code_page):
        """Sets the code_page of this StoreApp.


        :param code_page: The code_page of this StoreApp.  # noqa: E501
        :type: str
        """

        self._code_page = code_page

    @property
    def create_time(self):
        """Gets the create_time of this StoreApp.  # noqa: E501


        :return: The create_time of this StoreApp.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this StoreApp.


        :param create_time: The create_time of this StoreApp.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def desc(self):
        """Gets the desc of this StoreApp.  # noqa: E501


        :return: The desc of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._desc

    @desc.setter
    def desc(self, desc):
        """Sets the desc of this StoreApp.


        :param desc: The desc of this StoreApp.  # noqa: E501
        :type: str
        """

        self._desc = desc

    @property
    def download_count(self):
        """Gets the download_count of this StoreApp.  # noqa: E501


        :return: The download_count of this StoreApp.  # noqa: E501
        :rtype: int
        """
        return self._download_count

    @download_count.setter
    def download_count(self, download_count):
        """Sets the download_count of this StoreApp.


        :param download_count: The download_count of this StoreApp.  # noqa: E501
        :type: int
        """

        self._download_count = download_count

    @property
    def enterprise_id(self):
        """Gets the enterprise_id of this StoreApp.  # noqa: E501


        :return: The enterprise_id of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, enterprise_id):
        """Sets the enterprise_id of this StoreApp.


        :param enterprise_id: The enterprise_id of this StoreApp.  # noqa: E501
        :type: str
        """

        self._enterprise_id = enterprise_id

    @property
    def home_page(self):
        """Gets the home_page of this StoreApp.  # noqa: E501


        :return: The home_page of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._home_page

    @home_page.setter
    def home_page(self, home_page):
        """Sets the home_page of this StoreApp.


        :param home_page: The home_page of this StoreApp.  # noqa: E501
        :type: str
        """

        self._home_page = home_page

    @property
    def install_count(self):
        """Gets the install_count of this StoreApp.  # noqa: E501


        :return: The install_count of this StoreApp.  # noqa: E501
        :rtype: int
        """
        return self._install_count

    @install_count.setter
    def install_count(self, install_count):
        """Sets the install_count of this StoreApp.


        :param install_count: The install_count of this StoreApp.  # noqa: E501
        :type: int
        """

        self._install_count = install_count

    @property
    def install_status(self):
        """Gets the install_status of this StoreApp.  # noqa: E501


        :return: The install_status of this StoreApp.  # noqa: E501
        :rtype: bool
        """
        return self._install_status

    @install_status.setter
    def install_status(self, install_status):
        """Sets the install_status of this StoreApp.


        :param install_status: The install_status of this StoreApp.  # noqa: E501
        :type: bool
        """

        self._install_status = install_status

    @property
    def introduction(self):
        """Gets the introduction of this StoreApp.  # noqa: E501


        :return: The introduction of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._introduction

    @introduction.setter
    def introduction(self, introduction):
        """Sets the introduction of this StoreApp.


        :param introduction: The introduction of this StoreApp.  # noqa: E501
        :type: str
        """

        self._introduction = introduction

    @property
    def is_official(self):
        """Gets the is_official of this StoreApp.  # noqa: E501


        :return: The is_official of this StoreApp.  # noqa: E501
        :rtype: bool
        """
        return self._is_official

    @is_official.setter
    def is_official(self, is_official):
        """Sets the is_official of this StoreApp.


        :param is_official: The is_official of this StoreApp.  # noqa: E501
        :type: bool
        """

        self._is_official = is_official

    @property
    def joint_cloud_id(self):
        """Gets the joint_cloud_id of this StoreApp.  # noqa: E501


        :return: The joint_cloud_id of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._joint_cloud_id

    @joint_cloud_id.setter
    def joint_cloud_id(self, joint_cloud_id):
        """Sets the joint_cloud_id of this StoreApp.


        :param joint_cloud_id: The joint_cloud_id of this StoreApp.  # noqa: E501
        :type: str
        """

        self._joint_cloud_id = joint_cloud_id

    @property
    def logo(self):
        """Gets the logo of this StoreApp.  # noqa: E501


        :return: The logo of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this StoreApp.


        :param logo: The logo of this StoreApp.  # noqa: E501
        :type: str
        """

        self._logo = logo

    @property
    def name(self):
        """Gets the name of this StoreApp.  # noqa: E501


        :return: The name of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StoreApp.


        :param name: The name of this StoreApp.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def pic(self):
        """Gets the pic of this StoreApp.  # noqa: E501


        :return: The pic of this StoreApp.  # noqa: E501
        :rtype: list[str]
        """
        return self._pic

    @pic.setter
    def pic(self, pic):
        """Sets the pic of this StoreApp.


        :param pic: The pic of this StoreApp.  # noqa: E501
        :type: list[str]
        """

        self._pic = pic

    @property
    def price(self):
        """Gets the price of this StoreApp.  # noqa: E501


        :return: The price of this StoreApp.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this StoreApp.


        :param price: The price of this StoreApp.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def publish_type(self):
        """Gets the publish_type of this StoreApp.  # noqa: E501


        :return: The publish_type of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._publish_type

    @publish_type.setter
    def publish_type(self, publish_type):
        """Sets the publish_type of this StoreApp.


        :param publish_type: The publish_type of this StoreApp.  # noqa: E501
        :type: str
        """

        self._publish_type = publish_type

    @property
    def show_count(self):
        """Gets the show_count of this StoreApp.  # noqa: E501


        :return: The show_count of this StoreApp.  # noqa: E501
        :rtype: int
        """
        return self._show_count

    @show_count.setter
    def show_count(self, show_count):
        """Sets the show_count of this StoreApp.


        :param show_count: The show_count of this StoreApp.  # noqa: E501
        :type: int
        """

        self._show_count = show_count

    @property
    def start_count(self):
        """Gets the start_count of this StoreApp.  # noqa: E501


        :return: The start_count of this StoreApp.  # noqa: E501
        :rtype: int
        """
        return self._start_count

    @start_count.setter
    def start_count(self, start_count):
        """Sets the start_count of this StoreApp.


        :param start_count: The start_count of this StoreApp.  # noqa: E501
        :type: int
        """

        self._start_count = start_count

    @property
    def status(self):
        """Gets the status of this StoreApp.  # noqa: E501


        :return: The status of this StoreApp.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this StoreApp.


        :param status: The status of this StoreApp.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this StoreApp.  # noqa: E501


        :return: The update_time of this StoreApp.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this StoreApp.


        :param update_time: The update_time of this StoreApp.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreApp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreApp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppProbe(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'cmd': 'str',
        'failure_threshold': 'int',
        'http_header': 'str',
        'initial_delay_second': 'int',
        'is_used': 'bool',
        'mode': 'str',
        'path': 'str',
        'period_second': 'int',
        'port': 'int',
        'probe_id': 'str',
        'scheme': 'str',
        'service_id': 'str',
        'success_threshold': 'int',
        'timeout_second': 'int'
    }

    attribute_map = {
        'id': 'ID',
        'cmd': 'cmd',
        'failure_threshold': 'failure_threshold',
        'http_header': 'http_header',
        'initial_delay_second': 'initial_delay_second',
        'is_used': 'is_used',
        'mode': 'mode',
        'path': 'path',
        'period_second': 'period_second',
        'port': 'port',
        'probe_id': 'probe_id',
        'scheme': 'scheme',
        'service_id': 'service_id',
        'success_threshold': 'success_threshold',
        'timeout_second': 'timeout_second'
    }

    def __init__(self, id=None, cmd=None, failure_threshold=None, http_header=None, initial_delay_second=None, is_used=None, mode=None, path=None, period_second=None, port=None, probe_id=None, scheme=None, service_id=None, success_threshold=None, timeout_second=None):  # noqa: E501
        """StoreAppVersionTempleteAppProbe - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._cmd = None
        self._failure_threshold = None
        self._http_header = None
        self._initial_delay_second = None
        self._is_used = None
        self._mode = None
        self._path = None
        self._period_second = None
        self._port = None
        self._probe_id = None
        self._scheme = None
        self._service_id = None
        self._success_threshold = None
        self._timeout_second = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if cmd is not None:
            self.cmd = cmd
        if failure_threshold is not None:
            self.failure_threshold = failure_threshold
        if http_header is not None:
            self.http_header = http_header
        if initial_delay_second is not None:
            self.initial_delay_second = initial_delay_second
        if is_used is not None:
            self.is_used = is_used
        if mode is not None:
            self.mode = mode
        if path is not None:
            self.path = path
        if period_second is not None:
            self.period_second = period_second
        if port is not None:
            self.port = port
        if probe_id is not None:
            self.probe_id = probe_id
        if scheme is not None:
            self.scheme = scheme
        if service_id is not None:
            self.service_id = service_id
        if success_threshold is not None:
            self.success_threshold = success_threshold
        if timeout_second is not None:
            self.timeout_second = timeout_second

    @property
    def id(self):
        """Gets the id of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StoreAppVersionTempleteAppProbe.


        :param id: The id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def cmd(self):
        """Gets the cmd of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The cmd of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._cmd

    @cmd.setter
    def cmd(self, cmd):
        """Sets the cmd of this StoreAppVersionTempleteAppProbe.


        :param cmd: The cmd of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._cmd = cmd

    @property
    def failure_threshold(self):
        """Gets the failure_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The failure_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._failure_threshold

    @failure_threshold.setter
    def failure_threshold(self, failure_threshold):
        """Sets the failure_threshold of this StoreAppVersionTempleteAppProbe.


        :param failure_threshold: The failure_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._failure_threshold = failure_threshold

    @property
    def http_header(self):
        """Gets the http_header of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The http_header of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._http_header

    @http_header.setter
    def http_header(self, http_header):
        """Sets the http_header of this StoreAppVersionTempleteAppProbe.


        :param http_header: The http_header of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._http_header = http_header

    @property
    def initial_delay_second(self):
        """Gets the initial_delay_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The initial_delay_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._initial_delay_second

    @initial_delay_second.setter
    def initial_delay_second(self, initial_delay_second):
        """Sets the initial_delay_second of this StoreAppVersionTempleteAppProbe.


        :param initial_delay_second: The initial_delay_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._initial_delay_second = initial_delay_second

    @property
    def is_used(self):
        """Gets the is_used of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The is_used of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: bool
        """
        return self._is_used

    @is_used.setter
    def is_used(self, is_used):
        """Sets the is_used of this StoreAppVersionTempleteAppProbe.


        :param is_used: The is_used of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: bool
        """

        self._is_used = is_used

    @property
    def mode(self):
        """Gets the mode of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The mode of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this StoreAppVersionTempleteAppProbe.


        :param mode: The mode of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def path(self):
        """Gets the path of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The path of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this StoreAppVersionTempleteAppProbe.


        :param path: The path of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def period_second(self):
        """Gets the period_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The period_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._period_second

    @period_second.setter
    def period_second(self, period_second):
        """Sets the period_second of this StoreAppVersionTempleteAppProbe.


        :param period_second: The period_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._period_second = period_second

    @property
    def port(self):
        """Gets the port of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The port of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this StoreAppVersionTempleteAppProbe.


        :param port: The port of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def probe_id(self):
        """Gets the probe_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The probe_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this StoreAppVersionTempleteAppProbe.


        :param probe_id: The probe_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._probe_id = probe_id

    @property
    def scheme(self):
        """Gets the scheme of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The scheme of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._scheme

    @scheme.setter
    def scheme(self, scheme):
        """Sets the scheme of this StoreAppVersionTempleteAppProbe.


        :param scheme: The scheme of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._scheme = scheme

    @property
    def service_id(self):
        """Gets the service_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The service_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: str
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this StoreAppVersionTempleteAppProbe.


        :param service_id: The service_id of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: str
        """

        self._service_id = service_id

    @property
    def success_threshold(self):
        """Gets the success_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The success_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._success_threshold

    @success_threshold.setter
    def success_threshold(self, success_threshold):
        """Sets the success_threshold of this StoreAppVersionTempleteAppProbe.


        :param success_threshold: The success_threshold of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._success_threshold = success_threshold

    @property
    def timeout_second(self):
        """Gets the timeout_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501


        :return: The timeout_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :rtype: int
        """
        return self._timeout_second

    @timeout_second.setter
    def timeout_second(self, timeout_second):
        """Sets the timeout_second of this StoreAppVersionTempleteAppProbe.


        :param timeout_second: The timeout_second of this StoreAppVersionTempleteAppProbe.  # noqa: E501
        :type: int
        """

        self._timeout_second = timeout_second

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppProbe, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppProbe):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppPluginConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'attr': 'list[dict(str, object)]',
        'build_version': 'str',
        'create_time': 'str',
        'plugin_id': 'str',
        'plugin_key': 'str',
        'plugin_status': 'bool',
        'service_id': 'str',
        'service_meta_type': 'str'
    }

    attribute_map = {
        'id': 'ID',
        'attr': 'attr',
        'build_version': 'build_version',
        'create_time': 'create_time',
        'plugin_id': 'plugin_id',
        'plugin_key': 'plugin_key',
        'plugin_status': 'plugin_status',
        'service_id': 'service_id',
        'service_meta_type': 'service_meta_type'
    }

    def __init__(self, id=None, attr=None, build_version=None, create_time=None, plugin_id=None, plugin_key=None, plugin_status=None, service_id=None, service_meta_type=None):  # noqa: E501
        """StoreAppVersionTempleteAppPluginConfig - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._attr = None
        self._build_version = None
        self._create_time = None
        self._plugin_id = None
        self._plugin_key = None
        self._plugin_status = None
        self._service_id = None
        self._service_meta_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if attr is not None:
            self.attr = attr
        if build_version is not None:
            self.build_version = build_version
        if create_time is not None:
            self.create_time = create_time
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if plugin_key is not None:
            self.plugin_key = plugin_key
        if plugin_status is not None:
            self.plugin_status = plugin_status
        if service_id is not None:
            self.service_id = service_id
        if service_meta_type is not None:
            self.service_meta_type = service_meta_type

    @property
    def id(self):
        """Gets the id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StoreAppVersionTempleteAppPluginConfig.


        :param id: The id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def attr(self):
        """Gets the attr of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The attr of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._attr

    @attr.setter
    def attr(self, attr):
        """Sets the attr of this StoreAppVersionTempleteAppPluginConfig.


        :param attr: The attr of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._attr = attr

    @property
    def build_version(self):
        """Gets the build_version of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The build_version of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._build_version

    @build_version.setter
    def build_version(self, build_version):
        """Sets the build_version of this StoreAppVersionTempleteAppPluginConfig.


        :param build_version: The build_version of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._build_version = build_version

    @property
    def create_time(self):
        """Gets the create_time of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The create_time of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this StoreAppVersionTempleteAppPluginConfig.


        :param create_time: The create_time of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def plugin_id(self):
        """Gets the plugin_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The plugin_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this StoreAppVersionTempleteAppPluginConfig.


        :param plugin_id: The plugin_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def plugin_key(self):
        """Gets the plugin_key of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501

        插件类型  # noqa: E501

        :return: The plugin_key of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._plugin_key

    @plugin_key.setter
    def plugin_key(self, plugin_key):
        """Sets the plugin_key of this StoreAppVersionTempleteAppPluginConfig.

        插件类型  # noqa: E501

        :param plugin_key: The plugin_key of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._plugin_key = plugin_key

    @property
    def plugin_status(self):
        """Gets the plugin_status of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The plugin_status of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: bool
        """
        return self._plugin_status

    @plugin_status.setter
    def plugin_status(self, plugin_status):
        """Sets the plugin_status of this StoreAppVersionTempleteAppPluginConfig.


        :param plugin_status: The plugin_status of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: bool
        """

        self._plugin_status = plugin_status

    @property
    def service_id(self):
        """Gets the service_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The service_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this StoreAppVersionTempleteAppPluginConfig.


        :param service_id: The service_id of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._service_id = service_id

    @property
    def service_meta_type(self):
        """Gets the service_meta_type of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501


        :return: The service_meta_type of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :rtype: str
        """
        return self._service_meta_type

    @service_meta_type.setter
    def service_meta_type(self, service_meta_type):
        """Sets the service_meta_type of this StoreAppVersionTempleteAppPluginConfig.


        :param service_meta_type: The service_meta_type of this StoreAppVersionTempleteAppPluginConfig.  # noqa: E501
        :type: str
        """

        self._service_meta_type = service_meta_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppPluginConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppPluginConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempletePluginConfigGroupOption(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'attr_alt_value': 'str',
        'attr_default_value': 'str',
        'attr_info': 'str',
        'attr_name': 'str',
        'attr_type': 'str',
        'build_version': 'str',
        'is_change': 'bool',
        'plugin_id': 'str',
        'protocol': 'str',
        'service_meta_type': 'str'
    }

    attribute_map = {
        'id': 'ID',
        'attr_alt_value': 'attr_alt_value',
        'attr_default_value': 'attr_default_value',
        'attr_info': 'attr_info',
        'attr_name': 'attr_name',
        'attr_type': 'attr_type',
        'build_version': 'build_version',
        'is_change': 'is_change',
        'plugin_id': 'plugin_id',
        'protocol': 'protocol',
        'service_meta_type': 'service_meta_type'
    }

    def __init__(self, id=None, attr_alt_value=None, attr_default_value=None, attr_info=None, attr_name=None, attr_type=None, build_version=None, is_change=None, plugin_id=None, protocol=None, service_meta_type=None):  # noqa: E501
        """StoreAppVersionTempletePluginConfigGroupOption - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._attr_alt_value = None
        self._attr_default_value = None
        self._attr_info = None
        self._attr_name = None
        self._attr_type = None
        self._build_version = None
        self._is_change = None
        self._plugin_id = None
        self._protocol = None
        self._service_meta_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if attr_alt_value is not None:
            self.attr_alt_value = attr_alt_value
        if attr_default_value is not None:
            self.attr_default_value = attr_default_value
        if attr_info is not None:
            self.attr_info = attr_info
        if attr_name is not None:
            self.attr_name = attr_name
        if attr_type is not None:
            self.attr_type = attr_type
        if build_version is not None:
            self.build_version = build_version
        if is_change is not None:
            self.is_change = is_change
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if protocol is not None:
            self.protocol = protocol
        if service_meta_type is not None:
            self.service_meta_type = service_meta_type

    @property
    def id(self):
        """Gets the id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StoreAppVersionTempletePluginConfigGroupOption.


        :param id: The id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def attr_alt_value(self):
        """Gets the attr_alt_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The attr_alt_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._attr_alt_value

    @attr_alt_value.setter
    def attr_alt_value(self, attr_alt_value):
        """Sets the attr_alt_value of this StoreAppVersionTempletePluginConfigGroupOption.


        :param attr_alt_value: The attr_alt_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._attr_alt_value = attr_alt_value

    @property
    def attr_default_value(self):
        """Gets the attr_default_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The attr_default_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._attr_default_value

    @attr_default_value.setter
    def attr_default_value(self, attr_default_value):
        """Sets the attr_default_value of this StoreAppVersionTempletePluginConfigGroupOption.


        :param attr_default_value: The attr_default_value of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._attr_default_value = attr_default_value

    @property
    def attr_info(self):
        """Gets the attr_info of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The attr_info of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._attr_info

    @attr_info.setter
    def attr_info(self, attr_info):
        """Sets the attr_info of this StoreAppVersionTempletePluginConfigGroupOption.


        :param attr_info: The attr_info of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._attr_info = attr_info

    @property
    def attr_name(self):
        """Gets the attr_name of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The attr_name of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._attr_name

    @attr_name.setter
    def attr_name(self, attr_name):
        """Sets the attr_name of this StoreAppVersionTempletePluginConfigGroupOption.


        :param attr_name: The attr_name of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._attr_name = attr_name

    @property
    def attr_type(self):
        """Gets the attr_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The attr_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._attr_type

    @attr_type.setter
    def attr_type(self, attr_type):
        """Sets the attr_type of this StoreAppVersionTempletePluginConfigGroupOption.


        :param attr_type: The attr_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._attr_type = attr_type

    @property
    def build_version(self):
        """Gets the build_version of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The build_version of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._build_version

    @build_version.setter
    def build_version(self, build_version):
        """Sets the build_version of this StoreAppVersionTempletePluginConfigGroupOption.


        :param build_version: The build_version of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._build_version = build_version

    @property
    def is_change(self):
        """Gets the is_change of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The is_change of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: bool
        """
        return self._is_change

    @is_change.setter
    def is_change(self, is_change):
        """Sets the is_change of this StoreAppVersionTempletePluginConfigGroupOption.


        :param is_change: The is_change of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: bool
        """

        self._is_change = is_change

    @property
    def plugin_id(self):
        """Gets the plugin_id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The plugin_id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this StoreAppVersionTempletePluginConfigGroupOption.


        :param plugin_id: The plugin_id of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def protocol(self):
        """Gets the protocol of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The protocol of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this StoreAppVersionTempletePluginConfigGroupOption.


        :param protocol: The protocol of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def service_meta_type(self):
        """Gets the service_meta_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501


        :return: The service_meta_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :rtype: str
        """
        return self._service_meta_type

    @service_meta_type.setter
    def service_meta_type(self, service_meta_type):
        """Sets the service_meta_type of this StoreAppVersionTempletePluginConfigGroupOption.


        :param service_meta_type: The service_meta_type of this StoreAppVersionTempletePluginConfigGroupOption.  # noqa: E501
        :type: str
        """

        self._service_meta_type = service_meta_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempletePluginConfigGroupOption, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempletePluginConfigGroupOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""


    
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.apps_api import AppsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.apps_api.AppsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_recommended_app_list(self):
        """Test case for get_recommended_app_list

        get recommended app list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.store_app import StoreApp  # noqa: F401,E501


class AppListResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'list': 'list[StoreApp]',
        'page': 'int',
        'total': 'int'
    }

    attribute_map = {
        'list': 'list',
        'page': 'page',
        'total': 'total'
    }

    def __init__(self, list=None, page=None, total=None):  # noqa: E501
        """AppListResponse - a model defined in Swagger"""  # noqa: E501

        self._list = None
        self._page = None
        self._total = None
        self.discriminator = None

        if list is not None:
            self.list = list
        if page is not None:
            self.page = page
        if total is not None:
            self.total = total

    @property
    def list(self):
        """Gets the list of this AppListResponse.  # noqa: E501


        :return: The list of this AppListResponse.  # noqa: E501
        :rtype: list[StoreApp]
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this AppListResponse.


        :param list: The list of this AppListResponse.  # noqa: E501
        :type: list[StoreApp]
        """

        self._list = list

    @property
    def page(self):
        """Gets the page of this AppListResponse.  # noqa: E501


        :return: The page of this AppListResponse.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this AppListResponse.


        :param page: The page of this AppListResponse.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def total(self):
        """Gets the total of this AppListResponse.  # noqa: E501


        :return: The total of this AppListResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this AppListResponse.


        :param total: The total of this AppListResponse.  # noqa: E501
        :type: int
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppListResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""


    
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.store_app_version import StoreAppVersion  # noqa: E501
from swagger_client.rest import ApiException


class TestStoreAppVersion(unittest.TestCase):
    """StoreAppVersion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStoreAppVersion(self):
        """Test StoreAppVersion"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.store_app_version.StoreAppVersion()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ImageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hub_password': 'str',
        'hub_url': 'str',
        'hub_user': 'str',
        'is_trust': 'bool',
        'namespace': 'str'
    }

    attribute_map = {
        'hub_password': 'hub_password',
        'hub_url': 'hub_url',
        'hub_user': 'hub_user',
        'is_trust': 'is_trust',
        'namespace': 'namespace'
    }

    def __init__(self, hub_password=None, hub_url=None, hub_user=None, is_trust=None, namespace=None):  # noqa: E501
        """ImageInfo - a model defined in Swagger"""  # noqa: E501

        self._hub_password = None
        self._hub_url = None
        self._hub_user = None
        self._is_trust = None
        self._namespace = None
        self.discriminator = None

        if hub_password is not None:
            self.hub_password = hub_password
        if hub_url is not None:
            self.hub_url = hub_url
        if hub_user is not None:
            self.hub_user = hub_user
        if is_trust is not None:
            self.is_trust = is_trust
        if namespace is not None:
            self.namespace = namespace

    @property
    def hub_password(self):
        """Gets the hub_password of this ImageInfo.  # noqa: E501


        :return: The hub_password of this ImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._hub_password

    @hub_password.setter
    def hub_password(self, hub_password):
        """Sets the hub_password of this ImageInfo.


        :param hub_password: The hub_password of this ImageInfo.  # noqa: E501
        :type: str
        """

        self._hub_password = hub_password

    @property
    def hub_url(self):
        """Gets the hub_url of this ImageInfo.  # noqa: E501


        :return: The hub_url of this ImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._hub_url

    @hub_url.setter
    def hub_url(self, hub_url):
        """Sets the hub_url of this ImageInfo.


        :param hub_url: The hub_url of this ImageInfo.  # noqa: E501
        :type: str
        """

        self._hub_url = hub_url

    @property
    def hub_user(self):
        """Gets the hub_user of this ImageInfo.  # noqa: E501


        :return: The hub_user of this ImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._hub_user

    @hub_user.setter
    def hub_user(self, hub_user):
        """Sets the hub_user of this ImageInfo.


        :param hub_user: The hub_user of this ImageInfo.  # noqa: E501
        :type: str
        """

        self._hub_user = hub_user

    @property
    def is_trust(self):
        """Gets the is_trust of this ImageInfo.  # noqa: E501


        :return: The is_trust of this ImageInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_trust

    @is_trust.setter
    def is_trust(self, is_trust):
        """Sets the is_trust of this ImageInfo.


        :param is_trust: The is_trust of this ImageInfo.  # noqa: E501
        :type: bool
        """

        self._is_trust = is_trust

    @property
    def namespace(self):
        """Gets the namespace of this ImageInfo.  # noqa: E501


        :return: The namespace of this ImageInfo.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this ImageInfo.


        :param namespace: The namespace of this ImageInfo.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppDepService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dep_service_key': 'str'
    }

    attribute_map = {
        'dep_service_key': 'dep_service_key'
    }

    def __init__(self, dep_service_key=None):  # noqa: E501
        """StoreAppVersionTempleteAppDepService - a model defined in Swagger"""  # noqa: E501

        self._dep_service_key = None
        self.discriminator = None

        if dep_service_key is not None:
            self.dep_service_key = dep_service_key

    @property
    def dep_service_key(self):
        """Gets the dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501


        :return: The dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501
        :rtype: str
        """
        return self._dep_service_key

    @dep_service_key.setter
    def dep_service_key(self, dep_service_key):
        """Sets the dep_service_key of this StoreAppVersionTempleteAppDepService.


        :param dep_service_key: The dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501
        :type: str
        """

        self._dep_service_key = dep_service_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppDepService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppDepService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.store_app_version_templete_app import StoreAppVersionTempleteApp  # noqa: F401,E501
from swagger_client.models.store_app_version_templete_plugin import StoreAppVersionTempletePlugin  # noqa: F401,E501


class StoreAppVersionTemplete(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'apps': 'list[StoreAppVersionTempleteApp]',
        'group_key': 'str',
        'group_name': 'str',
        'group_version': 'str',
        'plugins': 'list[StoreAppVersionTempletePlugin]',
        'template_version': 'str'
    }

    attribute_map = {
        'apps': 'apps',
        'group_key': 'group_key',
        'group_name': 'group_name',
        'group_version': 'group_version',
        'plugins': 'plugins',
        'template_version': 'template_version'
    }

    def __init__(self, apps=None, group_key=None, group_name=None, group_version=None, plugins=None, template_version=None):  # noqa: E501
        """StoreAppVersionTemplete - a model defined in Swagger"""  # noqa: E501

        self._apps = None
        self._group_key = None
        self._group_name = None
        self._group_version = None
        self._plugins = None
        self._template_version = None
        self.discriminator = None

        if apps is not None:
            self.apps = apps
        if group_key is not None:
            self.group_key = group_key
        if group_name is not None:
            self.group_name = group_name
        if group_version is not None:
            self.group_version = group_version
        if plugins is not None:
            self.plugins = plugins
        if template_version is not None:
            self.template_version = template_version

    @property
    def apps(self):
        """Gets the apps of this StoreAppVersionTemplete.  # noqa: E501


        :return: The apps of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: list[StoreAppVersionTempleteApp]
        """
        return self._apps

    @apps.setter
    def apps(self, apps):
        """Sets the apps of this StoreAppVersionTemplete.


        :param apps: The apps of this StoreAppVersionTemplete.  # noqa: E501
        :type: list[StoreAppVersionTempleteApp]
        """

        self._apps = apps

    @property
    def group_key(self):
        """Gets the group_key of this StoreAppVersionTemplete.  # noqa: E501


        :return: The group_key of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: str
        """
        return self._group_key

    @group_key.setter
    def group_key(self, group_key):
        """Sets the group_key of this StoreAppVersionTemplete.


        :param group_key: The group_key of this StoreAppVersionTemplete.  # noqa: E501
        :type: str
        """

        self._group_key = group_key

    @property
    def group_name(self):
        """Gets the group_name of this StoreAppVersionTemplete.  # noqa: E501


        :return: The group_name of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this StoreAppVersionTemplete.


        :param group_name: The group_name of this StoreAppVersionTemplete.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    @property
    def group_version(self):
        """Gets the group_version of this StoreAppVersionTemplete.  # noqa: E501


        :return: The group_version of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: str
        """
        return self._group_version

    @group_version.setter
    def group_version(self, group_version):
        """Sets the group_version of this StoreAppVersionTemplete.


        :param group_version: The group_version of this StoreAppVersionTemplete.  # noqa: E501
        :type: str
        """

        self._group_version = group_version

    @property
    def plugins(self):
        """Gets the plugins of this StoreAppVersionTemplete.  # noqa: E501


        :return: The plugins of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: list[StoreAppVersionTempletePlugin]
        """
        return self._plugins

    @plugins.setter
    def plugins(self, plugins):
        """Sets the plugins of this StoreAppVersionTemplete.


        :param plugins: The plugins of this StoreAppVersionTemplete.  # noqa: E501
        :type: list[StoreAppVersionTempletePlugin]
        """

        self._plugins = plugins

    @property
    def template_version(self):
        """Gets the template_version of this StoreAppVersionTemplete.  # noqa: E501


        :return: The template_version of this StoreAppVersionTemplete.  # noqa: E501
        :rtype: str
        """
        return self._template_version

    @template_version.setter
    def template_version(self, template_version):
        """Sets the template_version of this StoreAppVersionTemplete.


        :param template_version: The template_version of this StoreAppVersionTemplete.  # noqa: E501
        :type: str
        """

        self._template_version = template_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTemplete, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTemplete):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppExtendMethodRule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_restart': 'int',
        'max_memory': 'int',
        'max_node': 'int',
        'min_memory': 'int',
        'min_node': 'int',
        'step_memory': 'int',
        'step_node': 'int'
    }

    attribute_map = {
        'is_restart': 'is_restart',
        'max_memory': 'max_memory',
        'max_node': 'max_node',
        'min_memory': 'min_memory',
        'min_node': 'min_node',
        'step_memory': 'step_memory',
        'step_node': 'step_node'
    }

    def __init__(self, is_restart=None, max_memory=None, max_node=None, min_memory=None, min_node=None, step_memory=None, step_node=None):  # noqa: E501
        """StoreAppVersionTempleteAppExtendMethodRule - a model defined in Swagger"""  # noqa: E501

        self._is_restart = None
        self._max_memory = None
        self._max_node = None
        self._min_memory = None
        self._min_node = None
        self._step_memory = None
        self._step_node = None
        self.discriminator = None

        if is_restart is not None:
            self.is_restart = is_restart
        if max_memory is not None:
            self.max_memory = max_memory
        if max_node is not None:
            self.max_node = max_node
        if min_memory is not None:
            self.min_memory = min_memory
        if min_node is not None:
            self.min_node = min_node
        if step_memory is not None:
            self.step_memory = step_memory
        if step_node is not None:
            self.step_node = step_node

    @property
    def is_restart(self):
        """Gets the is_restart of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The is_restart of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._is_restart

    @is_restart.setter
    def is_restart(self, is_restart):
        """Sets the is_restart of this StoreAppVersionTempleteAppExtendMethodRule.


        :param is_restart: The is_restart of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._is_restart = is_restart

    @property
    def max_memory(self):
        """Gets the max_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The max_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._max_memory

    @max_memory.setter
    def max_memory(self, max_memory):
        """Sets the max_memory of this StoreAppVersionTempleteAppExtendMethodRule.


        :param max_memory: The max_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._max_memory = max_memory

    @property
    def max_node(self):
        """Gets the max_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The max_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._max_node

    @max_node.setter
    def max_node(self, max_node):
        """Sets the max_node of this StoreAppVersionTempleteAppExtendMethodRule.


        :param max_node: The max_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._max_node = max_node

    @property
    def min_memory(self):
        """Gets the min_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The min_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._min_memory

    @min_memory.setter
    def min_memory(self, min_memory):
        """Sets the min_memory of this StoreAppVersionTempleteAppExtendMethodRule.


        :param min_memory: The min_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._min_memory = min_memory

    @property
    def min_node(self):
        """Gets the min_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The min_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._min_node

    @min_node.setter
    def min_node(self, min_node):
        """Sets the min_node of this StoreAppVersionTempleteAppExtendMethodRule.


        :param min_node: The min_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._min_node = min_node

    @property
    def step_memory(self):
        """Gets the step_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The step_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._step_memory

    @step_memory.setter
    def step_memory(self, step_memory):
        """Sets the step_memory of this StoreAppVersionTempleteAppExtendMethodRule.


        :param step_memory: The step_memory of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._step_memory = step_memory

    @property
    def step_node(self):
        """Gets the step_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501


        :return: The step_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :rtype: int
        """
        return self._step_node

    @step_node.setter
    def step_node(self, step_node):
        """Sets the step_node of this StoreAppVersionTempleteAppExtendMethodRule.


        :param step_node: The step_node of this StoreAppVersionTempleteAppExtendMethodRule.  # noqa: E501
        :type: int
        """

        self._step_node = step_node

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppExtendMethodRule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppExtendMethodRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppEnv(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attr_name': 'str',
        'attr_value': 'str',
        'is_change': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'attr_name': 'attr_name',
        'attr_value': 'attr_value',
        'is_change': 'is_change',
        'name': 'name'
    }

    def __init__(self, attr_name=None, attr_value=None, is_change=None, name=None):  # noqa: E501
        """StoreAppVersionTempleteAppEnv - a model defined in Swagger"""  # noqa: E501

        self._attr_name = None
        self._attr_value = None
        self._is_change = None
        self._name = None
        self.discriminator = None

        if attr_name is not None:
            self.attr_name = attr_name
        if attr_value is not None:
            self.attr_value = attr_value
        if is_change is not None:
            self.is_change = is_change
        if name is not None:
            self.name = name

    @property
    def attr_name(self):
        """Gets the attr_name of this StoreAppVersionTempleteAppEnv.  # noqa: E501


        :return: The attr_name of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :rtype: str
        """
        return self._attr_name

    @attr_name.setter
    def attr_name(self, attr_name):
        """Sets the attr_name of this StoreAppVersionTempleteAppEnv.


        :param attr_name: The attr_name of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :type: str
        """

        self._attr_name = attr_name

    @property
    def attr_value(self):
        """Gets the attr_value of this StoreAppVersionTempleteAppEnv.  # noqa: E501


        :return: The attr_value of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :rtype: str
        """
        return self._attr_value

    @attr_value.setter
    def attr_value(self, attr_value):
        """Sets the attr_value of this StoreAppVersionTempleteAppEnv.


        :param attr_value: The attr_value of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :type: str
        """

        self._attr_value = attr_value

    @property
    def is_change(self):
        """Gets the is_change of this StoreAppVersionTempleteAppEnv.  # noqa: E501


        :return: The is_change of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :rtype: bool
        """
        return self._is_change

    @is_change.setter
    def is_change(self, is_change):
        """Sets the is_change of this StoreAppVersionTempleteAppEnv.


        :param is_change: The is_change of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :type: bool
        """

        self._is_change = is_change

    @property
    def name(self):
        """Gets the name of this StoreAppVersionTempleteAppEnv.  # noqa: E501


        :return: The name of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StoreAppVersionTempleteAppEnv.


        :param name: The name of this StoreAppVersionTempleteAppEnv.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppEnv, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppEnv):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "rainbond-market-client"
VERSION = "0.0.1-dev"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="rainbond cloud app market OpenAPI.",
    author_email="576501057@qq.com",
    url="",
    keywords=["Swagger", "rainbond cloud app market OpenAPI."],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501
    """
)
